@@ -42,6 +42,8 @@ public:
     bool writeLabel(Report& report, const QString& deviceNode, const QString& newLabel) override;
     bool writeLabelOnline(Report& report, const QString& deviceNode, const QString& mountPoint, const QString& newLabel) override;
     bool updateUUID(Report& report, const QString& deviceNode) const override;
+    QString posixPermissions() const override { return implPosixPermissions();  };
+    void setPosixPermissions(const QString& permissions) override { implSetPosixPermissions(permissions); };
 
     CommandSupportType supportGetUsed() const override {
         return m_GetUsed;
